@@ -16,9 +16,9 @@
 * along with wxSmith; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
-* $Revision: 4504 $
-* $Id: wxsmithpluginregistrants.cpp 4504 2007-10-02 21:52:30Z byo $
-* $HeadURL: svn+ssh://byo@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/plugin/wxsmithpluginregistrants.cpp $
+* $Revision: 12304 $
+* $Id: processingdlg.cpp 12304 2021-03-16 23:28:31Z fuscated $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/contrib/lib_finder/processingdlg.cpp $
 */
 
 #include "processingdlg.h"
@@ -65,16 +65,16 @@ ProcessingDlg::ProcessingDlg(wxWindow* parent,LibraryDetectionManager& Manager,T
 	FlexGridSizer1 = new wxFlexGridSizer(0, 1, 0, 0);
 	StaticBoxSizer1 = new wxStaticBoxSizer(wxVERTICAL, this, _("Processing"));
 	Status = new wxStaticText(this, ID_STATICTEXT1, _("Waiting"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
-	StaticBoxSizer1->Add(Status, 0, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 0);
+	StaticBoxSizer1->Add(Status, 0, wxEXPAND, 0);
 	Gauge1 = new wxGauge(this, ID_GAUGE1, 100, wxDefaultPosition, wxSize(402,12), 0, wxDefaultValidator, _T("ID_GAUGE1"));
-	StaticBoxSizer1->Add(Gauge1, 1, wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-	FlexGridSizer1->Add(StaticBoxSizer1, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	StaticBoxSizer1->Add(Gauge1, 1, wxALIGN_CENTER_HORIZONTAL, 5);
+	FlexGridSizer1->Add(StaticBoxSizer1, 1, wxALL|wxALIGN_CENTER_VERTICAL, 5);
 	StopBtn = new wxButton(this, ID_BUTTON1, _("Stop"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_BUTTON1"));
-	FlexGridSizer1->Add(StopBtn, 1, wxBOTTOM|wxLEFT|wxRIGHT|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+	FlexGridSizer1->Add(StopBtn, 1, wxBOTTOM|wxLEFT|wxRIGHT|wxALIGN_CENTER_VERTICAL, 5);
 	SetSizer(FlexGridSizer1);
 	FlexGridSizer1->Fit(this);
 	FlexGridSizer1->SetSizeHints(this);
-	
+
 	Connect(ID_BUTTON1,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&ProcessingDlg::OnButton1Click);
 	//*)
 }
@@ -83,7 +83,7 @@ ProcessingDlg::~ProcessingDlg()
 {
 }
 
-void ProcessingDlg::OnButton1Click(wxCommandEvent& event)
+void ProcessingDlg::OnButton1Click(wxCommandEvent& /*event*//*event*/)
 {
     StopBtn->Disable();
     StopFlag = true;
@@ -235,6 +235,7 @@ void ProcessingDlg::ApplyResults(bool addOnly)
     }
 
     LibSelectDlg Dlg( this, Names, addOnly );
+    PlaceWindow(&Dlg);
     Dlg.SetSelections( Selected );
 
     if ( Dlg.ShowModal() == wxID_OK )
@@ -423,7 +424,7 @@ void ProcessingDlg::CheckFilter(
                     }
                 }
 
-                if ( platform::linux )
+                if ( platform::Linux )
                 {
                     if ( Platform==_T("lin") || Platform==_T("linux") )
                     {
@@ -477,7 +478,7 @@ void ProcessingDlg::CheckFilter(
                     }
                 }
 
-                if ( platform::unix )
+                if ( platform::Unix )
                 {
                     if ( Platform==_T("unix") || Platform==_T("un*x") )
                     {
@@ -579,6 +580,8 @@ void ProcessingDlg::CheckFilter(
             CheckFilter(OldBasePath,OldVars,OldCompilers,Config,Set,WhichFilter+1);
             break;
         }
+        default:
+            break;
     }
 }
 
