@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 6131 $
-* $Id: wxsmith.cpp 6131 2010-02-03 11:28:50Z jenslody $
-* $HeadURL: svn+ssh://jenslody@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/wxsmith.cpp $
+* $Revision: 13381 $
+* $Id: wxsmith.cpp 13381 2023-10-27 12:55:51Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/contrib/wxSmith/wxsmith.cpp $
 */
 
 #include "wxsmith.h"
@@ -28,14 +28,16 @@
 #include "wxsresourcefactory.h"
 #include "properties/wxsproperties.h"
 
-#include "cbauibook.h"
+#include <prep.h>
+#include <cbauibook.h>
 #include <projectloader_hooks.h>
-#include "manager.h"
-#include "configmanager.h"
+#include <manager.h>
+#include <configmanager.h>
 #include <projectmanager.h>
 #include <logmanager.h>
-#include <sqplus.h>
-#include <sc_base_types.h>
+#include <scriptingmanager.h>
+#include <scripting/bindings/sc_utils.h>
+#include <scripting/bindings/sc_typeinfo_all.h>
 
 namespace
 {
@@ -44,12 +46,11 @@ namespace
     const int ViewWxSmithResourceId = wxNewId();
     const int ViewWxSmithPropertyId = wxNewId();
 
-
     /* XPM */
     static const char * Events_xpm[] = {
     "16 16 2 1",
-    " 	c None",
-    ".	c #000000",
+    "     c None",
+    ".    c #000000",
     "                ",
     "    ..    ..    ",
     "   .        .   ",
@@ -74,17 +75,17 @@ namespace
     inline int GetBrowserPlacements() { return Manager::Get()->GetConfigManager(_T("wxsmith"))->ReadInt(_T("/browserplacements"),0); }
 }
 
-wxSmith* wxSmith::m_Singleton = 0;
+wxSmith* wxSmith::m_Singleton = nullptr;
 
 BEGIN_EVENT_TABLE(wxSmith, cbPlugin)
     EVT_UPDATE_UI(ViewWxSmithId,wxSmith::OnUpdateUI)
     EVT_UPDATE_UI(ViewWxSmithResourceId,wxSmith::OnUpdateUI)
     EVT_UPDATE_UI(ViewWxSmithPropertyId,wxSmith::OnUpdateUI)
-	EVT_MENU(ConfigureId,wxSmith::OnConfigure)
-	EVT_MENU(ViewWxSmithId,wxSmith::OnViewBrowsers)
-	EVT_MENU(ViewWxSmithResourceId,wxSmith::OnViewResourceBrowser)
-	EVT_MENU(ViewWxSmithPropertyId,wxSmith::OnViewPropertyBrowser)
-	EVT_MENU(-1,wxSmith::OnMenu)
+    EVT_MENU(ConfigureId,wxSmith::OnConfigure)
+    EVT_MENU(ViewWxSmithId,wxSmith::OnViewBrowsers)
+    EVT_MENU(ViewWxSmithResourceId,wxSmith::OnViewResourceBrowser)
+    EVT_MENU(ViewWxSmithPropertyId,wxSmith::OnViewPropertyBrowser)
+    EVT_MENU(-1,wxSmith::OnMenu)
 END_EVENT_TABLE()
 
 wxSmith::wxSmith()
@@ -100,7 +101,7 @@ void wxSmith::OnAttach()
     // No more instances of wxSmith class can be found here,
     // even if it's on another dll/so, m_Singleton will point
     // to different memory locations
-    wxASSERT(m_Singleton == 0);
+    wxASSERT(m_Singleton == nullptr);
 
     // Creating properties and resource browser
     BuildBrowsers();
@@ -113,21 +114,22 @@ void wxSmith::OnAttach()
 
     wxsResourceFactory::OnAttachAll();
 
-	// register event sink
+    // register event sink
     Manager::Get()->RegisterEventSink(cbEVT_PROJECT_OPEN, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectOpened));
-	Manager::Get()->RegisterEventSink(cbEVT_PROJECT_CLOSE, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectClose));
-	Manager::Get()->RegisterEventSink(cbEVT_PROJECT_RENAMED, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectRenamed));
+    Manager::Get()->RegisterEventSink(cbEVT_PROJECT_CLOSE, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectClose));
+    Manager::Get()->RegisterEventSink(cbEVT_PROJECT_RENAMED, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectRenamed));
+    Manager::Get()->RegisterEventSink(cbEVT_PROJECT_FILE_RENAMED, new cbEventFunctor<wxSmith, CodeBlocksEvent>(this, &wxSmith::OnProjectFileRenamed));
 
-	// register scripting stuff
+    // register scripting stuff
     RegisterScripting();
 }
 
 void wxSmith::BuildBrowserParents()
 {
     // Zero pointers to minimize segfault possibility ;)
-    m_Splitter = 0;
-    m_ResourceBrowserParent = 0;
-    m_PropertyBrowserParent = 0;
+    m_Splitter = nullptr;
+    m_ResourceBrowserParent = nullptr;
+    m_PropertyBrowserParent = nullptr;
 
     switch ( GetBrowserPlacements() )
     {
@@ -175,7 +177,7 @@ void wxSmith::BuildBrowserParents()
 
         default:
         {
-            cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetNotebook();
+            cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetUI().GetNotebook();
             wxASSERT(Notebook!=0);
 
             // Creating main splitting object
@@ -203,7 +205,8 @@ void wxSmith::BuildBrowsers()
 
     // Adding properties / events browser
     Sizer = new wxGridSizer(1);
-    wxsPropertyGridManager* PGManager = new wxsPropertyGridManager(m_PropertyBrowserParent,-1,wxDefaultPosition,wxDefaultSize,wxPG_TOOLBAR|wxTAB_TRAVERSAL);
+    wxsPropertyGridManager* PGManager = new wxsPropertyGridManager(m_PropertyBrowserParent,-1,wxDefaultPosition,wxDefaultSize,wxPG_TOOLBAR|wxTAB_TRAVERSAL|wxPG_SPLITTER_AUTO_CENTER);
+    PGManager->SetExtraStyle(wxPG_EX_HELP_AS_TOOLTIPS);
     PGManager->AddPage(_("Properties"));
     PGManager->AddPage(_("Events"),wxBitmap(Events_xpm));
     PGManager->SelectPage(0);
@@ -211,7 +214,7 @@ void wxSmith::BuildBrowsers()
     m_PropertyBrowserParent->SetSizer(Sizer);
 }
 
-void wxSmith::OnRelease(bool appShutDown)
+void wxSmith::OnRelease(cb_unused bool appShutDown)
 {
     UnregisterScripting();
 
@@ -221,7 +224,7 @@ void wxSmith::OnRelease(bool appShutDown)
         if ( i->second )
         {
             delete i->second;
-            i->second = 0;
+            i->second = nullptr;
         }
     }
     wxsExtResManager::Get()->DeleteAll();
@@ -232,43 +235,43 @@ void wxSmith::OnRelease(bool appShutDown)
 
     if ( m_Singleton == this )
     {
-        m_Singleton = 0;
+        m_Singleton = nullptr;
     }
 }
 
 cbConfigurationPanel* wxSmith::GetConfigurationPanel(wxWindow* parent)
 {
-	return new wxsSettings(parent);
+    return new wxsSettings(parent);
 }
 
 cbConfigurationPanel* wxSmith::GetProjectConfigurationPanel(wxWindow* parent, cbProject* project)
 {
     ProjectMapI i = m_ProjectMap.find(project);
-    if ( i == m_ProjectMap.end() ) return 0;
+    if ( i == m_ProjectMap.end() ) return nullptr;
     return i->second->GetProjectConfigurationPanel(parent);
 }
 
 void wxSmith::BuildMenu(wxMenuBar* menuBar)
 {
-    // Genearating separate wxSmith menu entry
-	wxMenu* SmithMenu = new wxMenu;
+    // Generating separate wxSmith menu entry
+    wxMenu* SmithMenu = new wxMenu;
 
-	wxsResourceFactory::BuildSmithMenu(SmithMenu);
+    wxsResourceFactory::BuildSmithMenu(SmithMenu);
 
-	SmithMenu->AppendSeparator();
-	SmithMenu->Append(ConfigureId,_("&Configure wxSmith for current project"));
+    SmithMenu->AppendSeparator();
+    SmithMenu->Append(ConfigureId,_("&Configure wxSmith for current project"));
 
-	int ToolsPos = menuBar->FindMenu(_("&Tools"));
-	if  ( ToolsPos == wxNOT_FOUND )
-	{
+    int ToolsPos = menuBar->FindMenu(_("&Tools"));
+    if  ( ToolsPos == wxNOT_FOUND )
+    {
         menuBar->Append(SmithMenu,_("&wxSmith"));
-	}
-	else
-	{
+    }
+    else
+    {
         menuBar->Insert(ToolsPos,SmithMenu,_("&wxSmith"));
-	}
+    }
 
-	// Generate entries in "view" menu
+    // Generate entries in "view" menu
     int idx = menuBar->FindMenu(_("&View"));
     if (idx != wxNOT_FOUND)
     {
@@ -289,6 +292,9 @@ void wxSmith::BuildMenu(wxMenuBar* menuBar)
                         view->InsertCheckItem(i,ViewWxSmithResourceId, _("wxSmith resource browser"), _("Toggle displaying the wxSmith resource browser"));
                         view->InsertCheckItem(i,ViewWxSmithPropertyId, _("wxSmith property browser"), _("Toggle displaying the wxSmith property browser"));
                         break;
+
+                    default:
+                        break;
                 }
                 return;
             }
@@ -305,56 +311,106 @@ void wxSmith::BuildMenu(wxMenuBar* menuBar)
                 view->AppendCheckItem(ViewWxSmithResourceId, _("wxSmith resource browser"), _("Toggle displaying the wxSmith resource browser"));
                 view->AppendCheckItem(ViewWxSmithPropertyId, _("wxSmith property browser"), _("Toggle displaying the wxSmith property browser"));
                 break;
+
+            default:
+                break;
         }
         return;
     }
 }
 
-void wxSmith::BuildModuleMenu(const ModuleType type, wxMenu* menu, const FileTreeData* data)
+void wxSmith::BuildModuleMenu(cb_unused const ModuleType type, cb_unused wxMenu* menu, const FileTreeData* /*data*/)
 {
 }
 
-bool wxSmith::BuildToolBar(wxToolBar* toolBar)
+bool wxSmith::BuildToolBar(cb_unused wxToolBar* toolBar)
 {
-	return false;
+    return false;
 }
 
 void wxSmith::OnProjectHook(cbProject* project,TiXmlElement* elem,bool loading)
 {
+    assert(project);
     wxsProject* Proj = GetSmithProject(project);
+    assert(Proj);
     if ( loading ) Proj->ReadConfiguration(elem);
     else           Proj->WriteConfiguration(elem);
 }
 
 void wxSmith::OnProjectOpened(CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
     wxsProject* wxsProj = GetSmithProject(Proj);
     wxsProj->UpdateName();
     Proj->SetModified(wxsProj->GetWasModifiedDuringLoad());
+    event.Skip();
 }
 
 void wxSmith::OnProjectClose(CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
-    ProjectMapI i = m_ProjectMap.find(Proj);
-    if ( i == m_ProjectMap.end() ) return;
-    delete i->second;
-    m_ProjectMap.erase(i);
+    ProjectMapI it = m_ProjectMap.find(Proj);
+    if (it != m_ProjectMap.end())
+    {
+        delete it->second;
+        m_ProjectMap.erase(it);
+    }
+
+    event.Skip();
 }
 
 void wxSmith::OnProjectRenamed(CodeBlocksEvent& event)
 {
-    event.Skip();
     cbProject* Proj = event.GetProject();
-    ProjectMapI i = m_ProjectMap.find(Proj);
-    if ( i == m_ProjectMap.end() ) return;
-    i->second->UpdateName();
+    ProjectMapI it = m_ProjectMap.find(Proj);
+    if (it != m_ProjectMap.end())
+        it->second->UpdateName();
+
+    event.Skip();
 }
 
-void wxSmith::OnConfigure(wxCommandEvent& event)
+void wxSmith::OnProjectFileRenamed(CodeBlocksEvent& event)
+{
+    cbProject *projectCB = event.GetProject();
+    ProjectMapI it = m_ProjectMap.find(projectCB);
+    if (it == m_ProjectMap.end())
+    {
+        event.Skip();
+        return;
+    }
+
+    wxsProject *projectWX = it->second;
+    if (projectWX)
+    {
+        const wxString projectPath(projectCB->GetCommonTopLevelPath());
+
+        // Get absolute old file name
+        wxFileName oldFileName(event.GetString(), event.GetOldFileName());
+        // Get relative (to project) old file name
+        oldFileName.MakeRelativeTo(projectPath);
+        const wxString relativeOldFullPath(oldFileName.GetFullPath(wxPATH_UNIX));
+
+        // Get absolute new file name
+        wxFileName newFileName(event.GetString(), event.GetNewFileName());
+        // Get relative (to project) new file name
+        newFileName.MakeRelativeTo(projectPath);
+        const wxString relativeNewFullPath(newFileName.GetFullPath(wxPATH_UNIX));
+
+        // Scan all resources looking if the renamed file belongs to any of them
+        // The file should not belong to more than one resource, but better safe than sorry...
+        const int resourceCount = projectWX->GetResourcesCount();
+        for (int resourceIndex = 0; resourceIndex < resourceCount; ++resourceIndex)
+        {
+            wxsResource *resource = projectWX->GetResource(resourceIndex);
+            if (resource->Rename(relativeOldFullPath, relativeNewFullPath))
+                projectWX->NotifyChange();
+        }
+    }
+
+    event.Skip();
+}
+
+void wxSmith::OnConfigure(cb_unused wxCommandEvent& event)
 {
     cbProject* Proj = Manager::Get()->GetProjectManager()->GetActiveProject();
     if ( Proj )
@@ -390,14 +446,14 @@ void wxSmith::OnViewPropertyBrowser(wxCommandEvent& event)
     Manager::Get()->ProcessEvent(evt);
 }
 
-void wxSmith::OnViewResourceBrowser(wxCommandEvent& event)
+void wxSmith::OnViewResourceBrowser(cb_unused wxCommandEvent& event)
 {
     CodeBlocksDockEvent evt(event.IsChecked() ? cbEVT_SHOW_DOCK_WINDOW : cbEVT_HIDE_DOCK_WINDOW);
     evt.pWindow = m_ResourceBrowserParent;
     Manager::Get()->ProcessEvent(evt);
 }
 
-void wxSmith::OnUpdateUI(wxUpdateUIEvent& event)
+void wxSmith::OnUpdateUI(cb_unused wxUpdateUIEvent& event)
 {
     wxMenuBar* Bar = Manager::Get()->GetAppFrame()->GetMenuBar();
 
@@ -413,6 +469,7 @@ cbProject* wxSmith::GetCBProject(wxsProject* Proj)
 
 wxsProject* wxSmith::GetSmithProject(cbProject* Proj)
 {
+    assert(Proj);
     ProjectMapI i = m_ProjectMap.find(Proj);
     if ( i == m_ProjectMap.end() )
     {
@@ -425,33 +482,12 @@ wxsProject* wxSmith::GetSmithProject(cbProject* Proj)
 
 void wxSmith::ShowResourcesTab()
 {
-    cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetNotebook();
+    cbAuiNotebook* Notebook = Manager::Get()->GetProjectManager()->GetUI().GetNotebook();
     Notebook->SetSelection( Notebook->GetPageIndex(m_Splitter) );
 }
 
-void wxSmith::RegisterScripting()
-{
-    Manager::Get()->GetScriptingManager();
-    if ( SquirrelVM::GetVMPtr() )
-    {
-        SqPlus::RegisterGlobal( &wxSmith::RecoverWxsFile, "WxsRecoverWxsFile" );
-    }
-}
-
-void wxSmith::UnregisterScripting()
-{
-    Manager::Get()->GetScriptingManager();
-    HSQUIRRELVM v = SquirrelVM::GetVMPtr();
-    if ( v )
-    {
-        sq_pushroottable(v);
-        sq_pushstring(v,"WxsRecoverWxsFile",-1);
-        sq_deleteslot(v,-2,false);
-        sq_poptop(v);
-    }
-}
-
-bool wxSmith::RecoverWxsFile( const wxString& WxsResourceSettings )
+/** \brief Function allowing to recover invalid wxs file */
+static bool RecoverWxsFile( const wxString& WxsResourceSettings )
 {
     wxSmith* This = wxSmith::Get();
     if ( !This ) return false;
@@ -463,6 +499,48 @@ bool wxSmith::RecoverWxsFile( const wxString& WxsResourceSettings )
     return project->RecoverWxsFile( WxsResourceSettings );
 }
 
+namespace ScriptBindings
+{
+
+SQInteger WxsRecoverWxsFile(HSQUIRRELVM v)
+{
+    // evn table, WxsResourceSettings
+    ExtractParams2<SkipParam, const wxString *> extractor(v);
+    if (!extractor.Process("WxsRecoverWxsFile"))
+        return extractor.ErrorMessage();
+    sq_pushbool(v, RecoverWxsFile(*extractor.p1));
+    return 1;
+}
+
+} // namespace ScriptBindings
+
+void wxSmith::RegisterScripting()
+{
+    HSQUIRRELVM vm = Manager::Get()->GetScriptingManager()->GetVM();
+    if (vm)
+    {
+        ScriptBindings::PreserveTop preserveTop(vm);
+
+        sq_pushroottable(vm);
+        ScriptBindings::BindMethod(vm, _SC("WxsRecoverWxsFile"), ScriptBindings::WxsRecoverWxsFile,
+                                   nullptr);
+        sq_poptop(vm); // Pop root table
+    }
+}
+
+void wxSmith::UnregisterScripting()
+{
+    HSQUIRRELVM v = Manager::Get()->GetScriptingManager()->GetVM();
+    if (v)
+    {
+        ScriptBindings::PreserveTop preserveTop(v);
+        sq_pushroottable(v);
+        sq_pushstring(v, _SC("WxsRecoverWxsFile"), -1);
+        sq_deleteslot(v, -2, false);
+        sq_poptop(v);
+    }
+}
+
 // TODO: Move to resources\wxwidgets
 /*
 
@@ -470,7 +548,7 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 {
     if ( !CheckIntegration() ) return;
 
-	wxString FileName = ::wxFileSelector(
+    wxString FileName = ::wxFileSelector(
         _("Select XRC file"),
         _T(""),
         _T(""),
@@ -486,7 +564,7 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     TiXmlElement* Resource;
     if ( !Doc.LoadFile() || !(Resource = Doc.FirstChildElement("resource")) )
     {
-    	wxMessageBox(_("Couldn't load XRC file."));
+        wxMessageBox(_("Couldn't load XRC file."));
         return;
     }
 
@@ -495,15 +573,15 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     TiXmlElement* Element = Resource->FirstChildElement("object");
     while ( Element )
     {
-    	const char* Class = Element->Attribute("class");
-    	const char* Name = Element->Attribute("name");
-    	if ( !Class || !Name ) continue;
+        const char* Class = Element->Attribute("class");
+        const char* Name = Element->Attribute("name");
+        if ( !Class || !Name ) continue;
 
-    	if ( !strcmp(Class,"wxDialog") ||
-    	     !strcmp(Class,"wxPanel") ||
-    	     !strcmp(Class,"wxFrame") )
+        if ( !strcmp(Class,"wxDialog") ||
+             !strcmp(Class,"wxPanel") ||
+             !strcmp(Class,"wxFrame") )
         {
-        	Resources.Add(cbC2U(Name));
+            Resources.Add(cbC2U(Name));
         }
 
         Element = Element->NextSiblingElement("object");
@@ -511,8 +589,8 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 
     if ( Resources.Count() == 0 )
     {
-    	wxMessageBox(_("Didn't find any editable resources"));
-    	return;
+        wxMessageBox(_("Didn't find any editable resources"));
+        return;
     }
 
     // Selecting resource to edit
@@ -520,11 +598,11 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
 
     if ( Resources.Count() == 1 )
     {
-    	Name = Resources[0];
+        Name = Resources[0];
     }
     else
     {
-        int Index = ::wxGetSingleChoiceIndex(
+        int Index = ::cbGetSingleChoiceIndex(
             _("Select resource to import"),
             _("Importing XRC"),
             Resources );
@@ -547,20 +625,20 @@ void wxSmith::OnImportXrc(wxCommandEvent& event)
     wxsItem* Test = wxsGEN(cbC2U(Element->Attribute("class")),0);
     if ( !Test )
     {
-    	// Something went wrong - default factory is not working ?
-    	Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Internal error - did not found one of base items when importing XRC")));
-    	return;
+        // Something went wrong - default factory is not working ?
+        Manager::Get()->GetLogManager()->DebugLog("wxSmith: Internal error - did not found one of base items when importing XRC");
+        return;
     }
 
     if ( !Test->XmlRead(Element,true,false) )
     {
-		if ( wxMessageBox(_("Resource was not loaded properly. Some widgets may be\n"
+        if ( wxMessageBox(_("Resource was not loaded properly. Some widgets may be\n"
                             "damaged or will be removed. Continue ?"),
                           _("XRC Load error"),
                           wxYES_NO|wxICON_QUESTION) == wxNO )
         {
-        	delete Test;
-        	return;
+            delete Test;
+            return;
         }
     }
     delete Test;
