@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 6219 $
-* $Id: wxsitem.cpp 6219 2010-05-12 14:12:01Z biplab $
-* $HeadURL: svn+ssh://jenslody@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.cpp $
+* $Revision: 13395 $
+* $Id: wxsitem.cpp 13395 2023-11-14 14:53:59Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxsitem.cpp $
 */
 
 #include "wxsitem.h"
@@ -26,8 +26,13 @@
 #include "wxsitemrestreedata.h"
 #include "wxseventseditor.h"
 #include "wxsitemeditor.h"
+
 #include <wx/menu.h>
 
+#include <clocale>
+
+#include <prep.h>
+
 using namespace wxsFlags;
 
 namespace
@@ -39,10 +44,10 @@ namespace
 wxsItem::wxsItem(wxsItemResData* ResourceData,const wxsItemInfo* Info,long PropertiesFlags,const wxsEventDesc* Events,const wxsStyleSet* StyleSet):
     m_Info(Info),
     m_Events(Events,this),
-    m_Parent(0),
+    m_Parent(nullptr),
     m_ResourceData(ResourceData),
     m_PropertiesFlags(PropertiesFlags),
-    m_LastPreview(0),
+    m_LastPreview(nullptr),
     m_IsSelected(false),
     m_IsExpanded(false)
 {
@@ -64,7 +69,7 @@ void wxsItem::OnEnumProperties(long Flags)
     if ( (Flags & flPropGrid) && (m_Parent != 0) )
     {
         // Parent item does take care of enumerating properties if we are
-        // ceating property grid
+        // creating property grid
         m_Parent->OnEnumChildProperties(this,Flags);
     }
     else
@@ -120,6 +125,7 @@ void wxsItem::OnBuildDeclarationsCode()
             AddDeclaration(GetUserClass() + (IsPointer() ? _T("* ") : _T(" ") ) + GetVarName() + _T(";"));
             return;
 
+        case wxsUnknownLanguage: // fall-through
         default:
             wxsCodeMarks::Unknown(_T("wxsItem::OnBuildDeclarationsCode"),GetLanguage());
     }
@@ -159,6 +165,7 @@ void wxsItem::OnBuildEventsConnectingCode()
             Events.GenerateBindingCode(GetCoderContext(),IdString,VarNameString);
             return;
         }
+        case wxsUnknownLanguage: // fall-through
         default:
         {
             wxsCodeMarks::Unknown(_T("wxsItem::OnBuildEventsConnectingCode"),GetLanguage());
@@ -177,8 +184,8 @@ void wxsItem::OnBuildIdCode()
             wxString Name = GetIdName();
             if ( !wxsPredefinedIDs::Check(Name) )
             {
-                wxString Enumeration = _T("static const long ") + Name + _T(";");
-                wxString Initialization =  + _T("const long ") + GetResourceData()->GetClassName() + _T("::") + Name + _T(" = wxNewId();");
+                wxString Enumeration = _T("static const wxWindowID ") + Name + _T(";");
+                wxString Initialization =  + _T("const wxWindowID ") + GetResourceData()->GetClassName() + _T("::") + Name + _T(" = wxNewId();");
                 if ( GetCoderContext()->m_IdEnumerations.Index(Enumeration) == wxNOT_FOUND )
                 {
                     AddIdCode(Enumeration,Initialization);
@@ -187,6 +194,7 @@ void wxsItem::OnBuildIdCode()
             return;
         }
 
+        case wxsUnknownLanguage: // fall-through
         default:
             wxsCodeMarks::Unknown(_T("wxsItem::OnBuildIdCode"),GetLanguage());
     }
@@ -232,49 +240,30 @@ void wxsItem::BuildSetupWindowCode()
             if ( PropertiesFlags&flColours )
             {
                 wxString FGCol = m_BaseProperties.m_Fg.BuildCode(GetCoderContext());
-                #if wxCHECK_VERSION(2, 9, 0)
                 if ( !FGCol.empty() ) Codef(_T("%ASetForegroundColour(%s);\n"),FGCol.wx_str());
-                #else
-                if ( !FGCol.empty() ) Codef(_T("%ASetForegroundColour(%s);\n"),FGCol.c_str());
-                #endif
 
                 wxString BGCol = m_BaseProperties.m_Bg.BuildCode(GetCoderContext());
-                #if wxCHECK_VERSION(2, 9, 0)
                 if ( !BGCol.empty() ) Codef(_T("%ASetBackgroundColour(%s);\n"),BGCol.wx_str());
-                #else
-                if ( !BGCol.empty() ) Codef(_T("%ASetBackgroundColour(%s);\n"),BGCol.c_str());
-                #endif
             }
 
             if ( PropertiesFlags&flFont )
             {
                 wxString FontVal = m_BaseProperties.m_Font.BuildFontCode(GetVarName() + _T("Font"), GetCoderContext());
                 if ( !FontVal.empty() )
-                {
-                    #if wxCHECK_VERSION(2, 9, 0)
                     Codef(_T("%s%ASetFont(%sFont);\n"),FontVal.wx_str(),GetVarName().wx_str());
-                    #else
-                    Codef(_T("%s%ASetFont(%sFont);\n"),FontVal.c_str(),GetVarName().c_str());
-                    #endif
-                }
             }
 
-            #if wxCHECK_VERSION(2, 9, 0)
-            if ( (PropertiesFlags&flToolTip)  && !m_BaseProperties.m_ToolTip.IsEmpty()  )   Codef(_T("%ASetToolTip(%t);\n"),m_BaseProperties.m_ToolTip.wx_str());
-            if ( (PropertiesFlags&flHelpText) && !m_BaseProperties.m_HelpText.IsEmpty() )   Codef(_T("%ASetHelpText(%t);\n"),m_BaseProperties.m_HelpText.wx_str());
-            #else
-            if ( (PropertiesFlags&flToolTip)  && !m_BaseProperties.m_ToolTip.IsEmpty()  )   Codef(_T("%ASetToolTip(%t);\n"),m_BaseProperties.m_ToolTip.c_str());
-            if ( (PropertiesFlags&flHelpText) && !m_BaseProperties.m_HelpText.IsEmpty() )   Codef(_T("%ASetHelpText(%t);\n"),m_BaseProperties.m_HelpText.c_str());
-            #endif
+            if ( (PropertiesFlags&flToolTip)   && !m_BaseProperties.m_ToolTip.IsEmpty()  )
+                Codef(_T("%ASetToolTip(%t);\n"),m_BaseProperties.m_ToolTip.wx_str());
+            if ( (PropertiesFlags&flHelpText)  && !m_BaseProperties.m_HelpText.IsEmpty() )
+                Codef(_T("%ASetHelpText(%t);\n"),m_BaseProperties.m_HelpText.wx_str());
             if ( (PropertiesFlags&flExtraCode) && !m_BaseProperties.m_ExtraCode.IsEmpty() )
             {
                 wxString& ExtraCode = m_BaseProperties.m_ExtraCode;
                 AddBuildingCode(ExtraCode);
                 // Adding extra \n character if it's not presend in extra code
                 if ( ExtraCode.GetChar(ExtraCode.Length()-1) != _T('\n') )
-                {
                     AddBuildingCode(_T("\n"));
-                }
             }
 
             if ( m_BaseProperties.m_StyleSet && m_BaseProperties.m_ExStyleBits )
@@ -282,17 +271,14 @@ void wxsItem::BuildSetupWindowCode()
                 wxString ExStyleStr = m_BaseProperties.m_StyleSet->GetString(m_BaseProperties.m_ExStyleBits,true,wxsCPP);
                 if ( ExStyleStr != _T("0") )
                 {
-                    #if wxCHECK_VERSION(2, 9, 0)
                     Codef(_T("%ASetExtraStyle( %AGetExtraStyle() | %s );\n"),ExStyleStr.wx_str());
-                    #else
-                    Codef(_T("%ASetExtraStyle( %AGetExtraStyle() | %s );\n"),ExStyleStr.c_str());
-                    #endif
                 }
             }
 
             return;
         }
 
+        case wxsUnknownLanguage: // fall-through
         default:
         {
             wxsCodeMarks::Unknown(_T("wxsItem::BuildSetupWindowCode"),GetLanguage());
@@ -453,6 +439,7 @@ wxString wxsItem::GetCreatePrefix(wxsCodingLang Language)
             if ( IsPointer()  ) return GetVarName() + _T(" = new ") + GetUserClass();
             return GetVarName() + _T(".Create");
 
+        case wxsUnknownLanguage: // fall-through
         default:
             wxsCodeMarks::Unknown(_T("wxsItem::GetCreatePrefix"),Language);
     }
@@ -468,6 +455,7 @@ wxString wxsItem::GetAccessPrefix(wxsCodingLang Language)
             if ( IsPointer()  ) return GetVarName() + _T("->");
             return GetVarName() + _T(".");
 
+        case wxsUnknownLanguage: // fall-through
         default:
             wxsCodeMarks::Unknown(_T("wxsItem::GetAccessPrefix"),Language);
     }
@@ -503,7 +491,22 @@ void wxsItem::Codef(const wxChar* Fmt,...)
     va_list ap;
     va_start(ap,Fmt);
 
-    Codef(GetCoderContext(),Fmt,GetCoderContext()->m_BuildingCode,ap);
+    Codef(GetCoderContext(), Fmt, GetCoderContext()->m_BuildingCode, ap);
+
+    va_end(ap);
+}
+void wxsItem::Codef(const wxString &Fmt,...)
+{
+    if ( !GetCoderContext() )
+    {
+        // TODO: Debug log
+        return;
+    }
+
+    va_list ap;
+    va_start(ap,Fmt.wx_str());
+
+    Codef(GetCoderContext(), Fmt.c_str(), GetCoderContext()->m_BuildingCode, ap);
 
     va_end(ap);
 }
@@ -515,6 +518,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
     wxsCodingLang Language = Context->m_Language;
     wxString WindowParent = Context->m_WindowParent;
     long Flags = Context->m_Flags;
+    const bool Translation = m_ResourceData->GetTranslation();
 
     while ( *Fmt )
     {
@@ -548,6 +552,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << GetParent()->GetVarName(); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -556,6 +561,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << _T("(&") << GetParent()->GetVarName() << _T(")"); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -566,6 +572,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 switch ( Language )
                                 {
                                     case wxsCPP: Result << _T("this"); break;
+                                    case wxsUnknownLanguage: // fall-through
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
@@ -581,6 +588,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << _T("(*") << GetParent()->GetVarName() << _T(")"); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -589,6 +597,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << GetParent()->GetVarName(); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -599,6 +608,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 switch ( Language )
                                 {
                                     case wxsCPP: Result << _T("(*this)"); break;
+                                    case wxsUnknownLanguage: // fall-through
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
@@ -610,6 +620,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                             switch ( Language )
                             {
                                 case wxsCPP: Result << GetIdName(); break;
+                                case wxsUnknownLanguage: // fall-through
                                 default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                             }
                             break;
@@ -644,6 +655,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 switch ( Language )
                                 {
                                     case wxsCPP: Result << _T("this"); break;
+                                    case wxsUnknownLanguage: // fall-through
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
@@ -654,6 +666,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << GetVarName(); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -662,6 +675,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << _T("(&") << GetVarName() << _T(")"); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -689,6 +703,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 switch ( Language )
                                 {
                                     case wxsCPP: Result << _T("(*this)"); break;
+                                    case wxsUnknownLanguage: // fall-through
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
@@ -699,6 +714,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << _T("(*") << GetVarName() << _T(")"); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -707,6 +723,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                     switch ( Language )
                                     {
                                         case wxsCPP: Result << GetVarName(); break;
+                                        case wxsUnknownLanguage: // fall-through
                                         default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                     }
                                 }
@@ -742,7 +759,14 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('V'):
                         {
-                            Result << _T("wxDefaultValidator");
+                            if ( Flags & flValidator && !m_BaseProperties.m_Validator.IsEmpty() )
+                            {
+                                Result << m_BaseProperties.m_Validator;
+                            }
+                            else
+                            {
+                                Result << _T("wxDefaultValidator");
+                            }
                             break;
                         }
 
@@ -751,6 +775,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                             switch ( Language )
                             {
                                 case wxsCPP: Result << WindowParent; break;
+                                case wxsUnknownLanguage: // fall-through
                                 default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                             }
                             break;
@@ -780,9 +805,19 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 Result.Append(_T('-'));
                                 Dec = -Dec;
                             }
-                            int Pos = 0;
-                            do Buff[Pos++] = _T('0') + (Dec%10), Dec /= 10; while ( Dec );
-                            while ( --Pos>=0 ) Result.Append(Buff[Pos]);
+                            int iPos = 0;
+                            do Buff[iPos++] = _T('0') + (Dec%10), Dec /= 10; while ( Dec );
+                            while ( --iPos>=0 ) Result.Append(Buff[iPos]);
+                            break;
+                        }
+
+                        case _T('f'):
+                        {
+                            double F = va_arg(ap,double);
+                            // handle locale decimal points correctly (always convert them to "dot")
+                            wxString sF; sF << F;
+                            sF.Replace(wxString::FromUTF8(localeconv()->decimal_point), wxT("."));
+                            Result << sF;
                             break;
                         }
 
@@ -841,6 +876,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                         switch ( Language )
                                         {
                                             case wxsCPP: Result << Child->GetVarName(); break;
+                                            case wxsUnknownLanguage: // fall-through
                                             default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                         }
                                     }
@@ -849,6 +885,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                         switch ( Language )
                                         {
                                             case wxsCPP: Result << _T("(&") << Child->GetVarName() << _T(")"); break;
+                                            case wxsUnknownLanguage: // fall-through
                                             default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                         }
                                     }
@@ -861,8 +898,8 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('p'):
                         {
-                            wxsPositionData* Pos = va_arg(ap,wxsPositionData*);
-                            Result << Pos->GetPositionCode(Context);
+                            wxsPositionData* PosD = va_arg(ap,wxsPositionData*);
+                            Result << PosD->GetPositionCode(Context);
                             break;
                         }
 
@@ -880,6 +917,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                         switch ( Language )
                                         {
                                             case wxsCPP: Result << _T("(*") << Child->GetVarName() << _T(")"); break;
+                                            case wxsUnknownLanguage: // fall-through
                                             default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                         }
                                     }
@@ -888,6 +926,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                         switch ( Language )
                                         {
                                             case wxsCPP: Result << Child->GetVarName(); break;
+                                            case wxsUnknownLanguage: // fall-through
                                             default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                         }
                                     }
@@ -911,7 +950,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                         case _T('t'):
                         {
                             wxChar* String = va_arg(ap,wxChar*);
-                            Result << wxsCodeMarks::WxString(Language,String?String:_T(""),true);
+                            Result << wxsCodeMarks::WxString(Language,String?String:_T(""),Translation);
                             break;
                         }
 
@@ -923,6 +962,7 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
                                 switch ( Language )
                                 {
                                     case wxsCPP: Result << Var; break;
+                                    case wxsUnknownLanguage: // fall-through
                                     default: wxsCodeMarks::Unknown(_T("wxString wxsItem::Codef"),Language);
                                 }
                             }
@@ -931,18 +971,14 @@ void wxsItem::Codef(wxsCoderContext* Context,const wxChar* Fmt,wxString& Result,
 
                         case _T('z'):
                         {
-                            wxsSizeData* Size = va_arg(ap,wxsSizeData*);
-                            Result << Size->GetSizeCode(Context);
+                            wxsSizeData* SizeD = va_arg(ap,wxsSizeData*);
+                            Result << SizeD->GetSizeCode(Context);
                             break;
                         }
 
                         default:
                         {
-                            #if wxCHECK_VERSION(2, 9, 0)
                             Result.Append(*Fmt);
-                            #else
-                            *Result.Append(*Fmt);
-                            #endif
                         }
                     }
                     Fmt++;
@@ -1015,7 +1051,7 @@ wxString wxsItem::GetUserClass()
     return GetClassName();
 }
 
-wxString wxsItem::OnGetTreeLabel(int& Image)
+wxString wxsItem::OnGetTreeLabel(cb_unused int& Image)
 {
     if ( GetPropertiesFlags()&flVariable && !IsRootItem() )
     {
@@ -1048,17 +1084,13 @@ wxString wxsItem::GetIdName()
 wxSize wxsItem::Size(wxWindow* Parent)
 {
     const wxSize minSize = GetBaseProps()->m_MinSize.GetSize(Parent);
-    if ( minSize != wxDefaultSize )
-    {
+    if (minSize != wxDefaultSize)
         return minSize;
-    }
-    else
-    {
-        return GetBaseProps()->m_Size.GetSize(Parent);
-    }
+
+    return GetBaseProps()->m_Size.GetSize(Parent);
 }
 
-bool wxsItem::OnMouseDClick(wxWindow* Preview,int PosX,int PosY)
+bool wxsItem::OnMouseDClick(cb_unused wxWindow* Preview,cb_unused int PosX,int cb_unused PosY)
 {
     // Search for first event (skip all categories)
     for ( int i=0; i<GetEvents().GetCount(); i++ )
@@ -1069,6 +1101,9 @@ bool wxsItem::OnMouseDClick(wxWindow* Preview,int PosX,int PosY)
             case wxsEventDesc::EndOfList:
                 break;
 
+            case wxsEventDesc::Id:      // fall-through
+            case wxsEventDesc::IdRange: // fall-through
+            case wxsEventDesc::NoId:    // fall-through
             default:
                 // Found event, now let's try to add handler for it
                 return wxsEventsEditor::Get().GotoOrBuildEvent(this,i,wxsPGRID());
@@ -1078,7 +1113,7 @@ bool wxsItem::OnMouseDClick(wxWindow* Preview,int PosX,int PosY)
     return false;
 }
 
-bool wxsItem::OnMouseRightClick(wxWindow* Preview,int PosX,int PosY)
+bool wxsItem::OnMouseRightClick(cb_unused wxWindow* Preview,cb_unused int PosX,cb_unused int PosY)
 {
     wxMenu Popup;
     OnPreparePopup(&Popup);
