@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 5243 $
-* $Id: wxsitemresdata.cpp 5243 2008-10-06 19:31:44Z killerbot $
-* $HeadURL: svn+ssh://jenslody@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxsitemresdata.cpp $
+* $Revision: 13381 $
+* $Id: wxsitemresdata.cpp 13381 2023-10-27 12:55:51Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxsitemresdata.cpp $
 */
 
 #include "wxsitemresdata.h"
@@ -28,10 +28,11 @@
 #include "wxsflags.h"
 #include "../wxscoder.h"
 
+#include <algorithm>
 #include <globals.h>
 #include <logmanager.h>
 #include <wx/clipbrd.h>
-#include <tinyxml/tinywxuni.h>
+#include <tinywxuni.h>
 
 #if defined(__WXMSW__) && defined(LoadImage)
     // Fix Windows winuser.h Header define of LoadImage.
@@ -43,7 +44,7 @@ using namespace wxsFlags;
 
 namespace
 {
-    const int ToolsTreeImageId = wxsResourceTree::LoadImage(_T("/images/misc_16x16.png"));
+    const int ToolsTreeImageId = wxsResourceTree::LoadImage(_T("images/wxsmith/tools16.png"));
 }
 
 wxsItemResData::wxsItemResData(
@@ -55,6 +56,7 @@ wxsItemResData::wxsItemResData(
     const wxString& ClassType,
     wxsCodingLang Language,
     bool UseForwardDeclarations,
+    bool WithTranslation,
     wxsResourceItemId TreeId,
     wxsItemEditor* Editor,
     wxsItemResFunctions* Functions):
@@ -62,6 +64,7 @@ wxsItemResData::wxsItemResData(
         m_SrcFileName(SrcFileName),
         m_HdrFileName(HdrFileName),
         m_XrcFileName(XrcFileName),
+        m_Translation(WithTranslation),
         m_ClassName(ClassName),
         m_ClassType(ClassType),
         m_Language(Language),
@@ -70,9 +73,9 @@ wxsItemResData::wxsItemResData(
         m_ToolsNodeIsExpanded(false),
         m_Editor(Editor),
         m_Functions(Functions),
-        m_RootItem(0),
-        m_RootSelection(0),
-        m_Preview(0),
+        m_RootItem(nullptr),
+        m_RootSelection(nullptr),
+        m_Preview(nullptr),
         m_Corrector(this),
         m_IsOK(false),
         m_LockCount(0),
@@ -130,8 +133,8 @@ wxsItemResData::~wxsItemResData()
         RebuildFiles();
     }
     delete m_RootItem;
-    m_RootItem = 0;
-    m_RootSelection = 0;
+    m_RootItem = nullptr;
+    m_RootSelection = nullptr;
     for ( int i=0; i<GetToolsCount(); i++ )
     {
         delete m_Tools[i];
@@ -274,20 +277,20 @@ bool wxsItemResData::LoadInMixedMode()
         {
             IdToXmlMapT IdToXmlMap;
 
-            TiXmlElement* Object = Extra->FirstChildElement("object");
-            while ( Object )
+            TiXmlElement* _Object = Extra->FirstChildElement("object");
+            while ( _Object )
             {
-                wxString IdName = cbC2U(Object->Attribute("name"));
+                wxString IdName = cbC2U(_Object->Attribute("name"));
                 if ( !IdName.empty() )
                 {
-                    IdToXmlMap[IdName] = Object;
+                    IdToXmlMap[IdName] = _Object;
                 }
-                else if ( Object->Attribute("root") )
+                else if ( _Object->Attribute("root") )
                 {
                     // Empty id simulates root node
-                    IdToXmlMap[_T("")] = Object;
+                    IdToXmlMap[_T("")] = _Object;
                 }
-                Object = Object->NextSiblingElement("object");
+                _Object = _Object->NextSiblingElement("object");
             }
 
             UpdateExtraDataReq(m_RootItem,IdToXmlMap);
@@ -341,7 +344,8 @@ bool wxsItemResData::LoadInSourceMode()
     TiXmlDocument Doc;
     if ( !TinyXML::LoadDocument(m_WxsFileName,&Doc)  )
     {
-        Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: Error loading wxs file (Col: %d, Row:%d): ") + cbC2U(Doc.ErrorDesc()),Doc.ErrorCol(),Doc.ErrorRow()));
+        Manager::Get()->GetLogManager()->DebugLog(wxString::Format("wxSmith: Error loading wxs file (Col: %d, Row: %d): %s",
+                                                                   Doc.ErrorCol(), Doc.ErrorRow(), cbC2U(Doc.ErrorDesc())));
         return false;
     }
 
@@ -412,6 +416,9 @@ bool wxsItemResData::Save()
 
         case flSource:
             return SaveInSourceMode();
+
+        default:
+            break;
     }
 
     return false;
@@ -525,6 +532,9 @@ void wxsItemResData::RebuildFiles()
             RebuildSourceCode();
             RebuildXrcFile();
             break;
+
+        default:
+            break;
     }
 }
 
@@ -591,7 +601,8 @@ void wxsItemResData::RebuildSourceCode()
             }
 
             // Add some initial headers
-            Context.AddHeader(_T("<wx/intl.h>"),_T(""),hfLocal|hfInPCH);
+            if (m_Translation)
+                Context.AddHeader(_T("<wx/intl.h>"),_T(""),hfLocal|hfInPCH);
             Context.AddHeader(_T("<wx/string.h>"),_T(""),hfLocal|hfInPCH);
             if ( m_PropertiesFilter & flMixed )
             {
@@ -623,6 +634,13 @@ void wxsItemResData::RebuildSourceCode()
                 InitializeCode(&Context),
                 false );
 
+            wxsCoder::Get()->AddCode(
+                m_SrcFileName,
+                wxsCodeMarks::Beg(wxsCPP,_T("Destroy"),m_ClassName),
+                wxsCodeMarks::End(wxsCPP),
+                DestroyCode(&Context),
+                false );
+
             wxsCoder::Get()->AddCode(
                 m_SrcFileName,
                 wxsCodeMarks::Beg(wxsCPP,_T("IdInit"),m_ClassName),
@@ -689,11 +707,12 @@ void wxsItemResData::RebuildSourceCode()
             }
 
             wxsCoder::Get()->Flush(500);
-            //Manager::Get()->GetLogManager()->DebugLog(F(_T("wxSmith: New code built in %d milis"),SW.Time()));
+            //Manager::Get()->GetLogManager()->DebugLog(wxString::Format("wxSmith: New code built in %ld ms", SW.Time()));
 
             break;
         }
 
+        case wxsUnknownLanguage: // fall-through
         default:
         {
             wxsCodeMarks::Unknown(_T("wxsItemResData::RebuildSourceCode"),m_Language);
@@ -702,15 +721,32 @@ void wxsItemResData::RebuildSourceCode()
 
 }
 
+/// Turn a string set into a sorted list and then generate a string from it in the form of prefix+item+suffix.
+/// The sorting is needed to prevent reshuffling of items when the hash function of the set changes, thus the generated
+/// code is always the same.
+wxString GenerateCodeFromSet(const wxsCoderContext::wxStringSet &set, const wxString &prefix, const wxString &suffix)
+{
+    std::vector<wxString> array;
+    array.reserve(set.size());
+    for (const wxString &item : set)
+        array.push_back(item);
+
+    std::sort(array.begin(), array.end());
+    wxString Code;
+    for (const wxString &item : array)
+    {
+        Code += prefix;
+        Code += item;
+        Code += suffix;
+    }
+    return Code;
+}
+
 wxString wxsItemResData::DeclarationsCode(wxsCoderContext* Ctx)
 {
     // Enumerate all class members
     wxString Code = _T("\n");
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_GlobalDeclarations.begin(); i!=Ctx->m_GlobalDeclarations.end(); ++i )
-    {
-        Code += *i;
-        Code += _T("\n");
-    }
+    Code += GenerateCodeFromSet(Ctx->m_GlobalDeclarations, wxEmptyString, wxT("\n"));
     return Code;
 }
 
@@ -731,11 +767,7 @@ wxString wxsItemResData::InitializeCode(wxsCoderContext* Ctx)
     wxString Code = _T("\n");
 
     // First there are local variables
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_LocalDeclarations.begin(); i!=Ctx->m_LocalDeclarations.end(); ++i )
-    {
-        Code += *i;
-        Code += _T("\n");
-    }
+    Code += GenerateCodeFromSet(Ctx->m_LocalDeclarations, wxEmptyString, wxT("\n"));
 
     if ( Code.Length()>1 )
     {
@@ -765,6 +797,19 @@ wxString wxsItemResData::InitializeCode(wxsCoderContext* Ctx)
     return Code;
 }
 
+wxString wxsItemResData::DestroyCode(wxsCoderContext* Ctx)
+{
+    wxString Code = _T("\n");
+
+    // If in source mode, add destroying code
+    if ( Ctx->m_Flags & flSource )
+    {
+        Code += Ctx->m_DestroyingCode;
+    }
+
+    return Code;
+}
+
 wxString wxsItemResData::IdInitCode(wxsCoderContext* Ctx)
 {
     wxString Code = _T("\n");
@@ -780,35 +825,16 @@ wxString wxsItemResData::HeadersCode(wxsCoderContext* Ctx)
 {
     wxString Code;
     // Enumerate global includes (those in header file)
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_GlobalHeaders.begin(); i!=Ctx->m_GlobalHeaders.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_ForwardDeclarations.begin(); i!=Ctx->m_ForwardDeclarations.end(); ++i )
-    {
-        Code += _T("\nclass ");
-        Code += *i;
-        Code += _T(";");
-    }
+    Code += GenerateCodeFromSet(Ctx->m_GlobalHeaders, wxT("\n#include "), wxEmptyString);
+    Code += GenerateCodeFromSet(Ctx->m_ForwardDeclarations, wxT("\nclass "), wxT(";"));
     return Code + _T("\n");
 }
 
 wxString wxsItemResData::HeadersNoPCHCode(wxsCoderContext* Ctx)
 {
     wxString Code;
-    // Enumerate global includes (those in header file)
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_GlobalHeadersNonPCH.begin(); i!=Ctx->m_GlobalHeadersNonPCH.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_ForwardDeclarationsNonPCH.begin(); i!=Ctx->m_ForwardDeclarationsNonPCH.end(); ++i )
-    {
-        Code += _T("\nclass ");
-        Code += *i;
-        Code += _T(";");
-    }
+    Code += GenerateCodeFromSet(Ctx->m_GlobalHeadersNonPCH, wxT("\n#include "), wxEmptyString);
+    Code += GenerateCodeFromSet(Ctx->m_ForwardDeclarationsNonPCH, wxT("\nclass "), wxT(";"));
     return Code + _T("\n");
 }
 
@@ -816,30 +842,12 @@ wxString wxsItemResData::HeadersAllCode(wxsCoderContext* Ctx)
 {
     wxString Code;
     // Enumerate global includes (those in header file)
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_GlobalHeaders.begin(); i!=Ctx->m_GlobalHeaders.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_GlobalHeadersNonPCH.begin(); i!=Ctx->m_GlobalHeadersNonPCH.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
-
+    Code += GenerateCodeFromSet(Ctx->m_GlobalHeaders, wxT("\n#include "), wxEmptyString);
+    Code += GenerateCodeFromSet(Ctx->m_GlobalHeadersNonPCH, wxT("\n#include "), wxEmptyString);
     // Enumerate all forward declarations
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_ForwardDeclarations.begin(); i!=Ctx->m_ForwardDeclarations.end(); ++i )
-    {
-        Code += _T("\nclass ");
-        Code += *i;
-        Code += _T(";");
-    }
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_ForwardDeclarationsNonPCH.begin(); i!=Ctx->m_ForwardDeclarationsNonPCH.end(); ++i )
-    {
-        Code += _T("\nclass ");
-        Code += *i;
-        Code += _T(";");
-    }
+    Code += GenerateCodeFromSet(Ctx->m_ForwardDeclarations, wxT("\nclass "), wxT(";"));
+    Code += GenerateCodeFromSet(Ctx->m_ForwardDeclarationsNonPCH, wxT("\nclass "), wxT(";"));
+
     return Code + _T("\n");
 }
 
@@ -857,27 +865,15 @@ wxString wxsItemResData::InternalHeadersCode(wxsCoderContext* Ctx)
 wxString wxsItemResData::InternalHeadersNoPCHCode(wxsCoderContext* Ctx)
 {
     wxString Code;
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_LocalHeadersNonPCH.begin(); i!=Ctx->m_LocalHeadersNonPCH.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
+    Code += GenerateCodeFromSet(Ctx->m_LocalHeadersNonPCH, wxT("\n#include "), wxEmptyString);
     return Code + _T("\n");
 }
 
 wxString wxsItemResData::InternalHeadersAllCode(wxsCoderContext* Ctx)
 {
     wxString Code;
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_LocalHeaders.begin(); i!=Ctx->m_LocalHeaders.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
-    for ( wxsCoderContext::wxStringSet::iterator i = Ctx->m_LocalHeadersNonPCH.begin(); i!=Ctx->m_LocalHeadersNonPCH.end(); ++i )
-    {
-        Code += _T("\n#include ");
-        Code += *i;
-    }
+    Code += GenerateCodeFromSet(Ctx->m_LocalHeaders, wxT("\n#include "), wxEmptyString);
+    Code += GenerateCodeFromSet(Ctx->m_LocalHeadersNonPCH, wxT("\n#include "), wxEmptyString);
     return Code + _T("\n");
 }
 
@@ -898,8 +894,8 @@ bool wxsItemResData::RebuildXrcFile()
 {
     // First - opening file
     TiXmlDocument Doc;
-    TiXmlElement* Resources;
-    TiXmlElement* Object;
+    TiXmlElement* Resources = nullptr;
+    TiXmlElement* Object = nullptr;
 
     if ( TinyXML::LoadDocument(m_XrcFileName,&Doc) )
     {
@@ -952,6 +948,7 @@ void wxsItemResData::BeginChange()
     {
         StoreTreeExpandState();
         wxsResourceTree::Get()->BlockSelect();
+        m_ExtraIsInvalid = false;
     }
 }
 
@@ -971,6 +968,9 @@ void wxsItemResData::EndChange()
         }
         if ( ValidateRootSelection() )
         {
+            if (m_ExtraIsInvalid && m_Editor)
+                m_Editor->RebuildQuickProps(m_RootSelection);
+
             m_RootSelection->NotifyPropertyChange(false);
         }
         else
@@ -987,9 +987,14 @@ void wxsItemResData::EndChange()
     }
 }
 
+void wxsItemResData::MarkExtraDataChanged()
+{
+    m_ExtraIsInvalid = true;
+}
+
 bool wxsItemResData::ValidateRootSelection()
 {
-    wxsItem* NewSelection = 0;
+    wxsItem* NewSelection = nullptr;
     if ( ValidateRootSelectionReq(m_RootItem,NewSelection) )
     {
         return true;
@@ -1091,7 +1096,7 @@ void wxsItemResData::Paste(wxsParent* Parent,int Position)
         {
             BeginChange();
             m_RootItem->ClearSelection();
-            m_RootSelection = 0;
+            m_RootSelection = nullptr;
             for ( int i=0; i<Cnt; i++ )
             {
                 wxsItem* Insert = Data.BuildItem(this,i);
@@ -1485,7 +1490,7 @@ bool wxsItemResData::HidePreview()
         return false;
     }
     m_Preview->Destroy();
-    m_Preview = 0;
+    m_Preview = nullptr;
     return true;
 }
 
