@@ -15,9 +15,9 @@
 * You should have received a copy of the GNU General Public License
 * along with wxSmith. If not, see <http://www.gnu.org/licenses/>.
 *
-* $Revision: 4850 $
-* $Id: wxwidgetsgui.cpp 4850 2008-01-29 21:45:49Z byo $
-* $HeadURL: svn+ssh://jenslody@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxwidgetsgui.cpp $
+* $Revision: 13381 $
+* $Id: wxwidgetsgui.cpp 13381 2023-10-27 12:55:51Z wh11204 $
+* $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/contrib/wxSmith/wxwidgets/wxwidgetsgui.cpp $
 */
 
 #include "wxwidgetsgui.h"
@@ -58,7 +58,7 @@ cbConfigurationPanel* wxWidgetsGUI::OnBuildConfigurationPanel(wxWindow* Parent)
 void wxWidgetsGUI::OnRebuildApplicationCode()
 {
     bool IsAnyXRC = false;
-    wxWidgetsRes* MainResPtr = 0;
+    wxWidgetsRes* MainResPtr = nullptr;
 
     size_t Count = GetProject()->GetResourcesCount();
     for ( size_t i=0; i<Count; i++ )
@@ -83,7 +83,9 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
     {
         case wxsCPP: NewCode = _T("\nbool wxsOK = true;\n")
                                _T("wxInitAllImageHandlers();\n"); break;
-        default:;
+        case wxsUnknownLanguage: // fall-through
+        default:
+            break;
     }
 
     bool InitAllXRCHandlers = m_CallInitAll && ( IsAnyXRC || !m_CallInitAllNecessary );
@@ -92,7 +94,9 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
         switch ( m_AppLanguage )
         {
             case wxsCPP: NewCode.Append(_T("wxXmlResource::Get()->InitAllHandlers();\n")); break;
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
 
@@ -105,7 +109,9 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
                 NewCode.Append(m_LoadedResources[i]);
                 NewCode.Append(_T("\"));\n"));
                 break;
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
 
@@ -118,13 +124,15 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
                 NewCode << MainResPtr->GetAppBuildingCode();
                 NewCode << _T("}\n");
                 break;
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
 
     wxsCoder::Get()->AddCode(
         GetProjectPath() + m_AppFile,
-        wxsCodeMarks::Beg(m_AppLanguage,_("AppInitialize")),
+        wxsCodeMarks::Beg(m_AppLanguage, _T("AppInitialize")),
         wxsCodeMarks::End(m_AppLanguage),
         NewCode);
 
@@ -149,7 +157,9 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
                 NewCode << _T("#include \"") << IncludeFile << _T("\"\n");
                 break;
             }
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
     if ( InitAllXRCHandlers || m_LoadedResources.Count() )
@@ -157,14 +167,18 @@ void wxWidgetsGUI::OnRebuildApplicationCode()
         switch ( m_AppLanguage )
         {
             case wxsCPP: NewCode.Append(_T("#include <wx/xrc/xmlres.h>\n")); break;
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
 
     switch ( m_AppLanguage )
     {
         case wxsCPP: NewCode.Append(_T("#include <wx/image.h>\n")); break;
-        default:;
+        case wxsUnknownLanguage: // fall-through
+        default:
+            break;
     }
 
     wxsCoder::Get()->AddCode(
@@ -183,6 +197,7 @@ bool wxWidgetsGUI::OnCheckIfApplicationManaged()
 bool wxWidgetsGUI::OnCreateApplicationBinding()
 {
     wxWidgetsGUIAppAdoptingDlg Dlg(0,this);
+    PlaceWindow(&Dlg);
     Dlg.ShowModal();
     return OnCheckIfApplicationManaged();
 }
@@ -302,7 +317,9 @@ bool wxWidgetsGUI::ScanForApp(ProjectFile* File)
             // TODO: Do extra checks of this OnInit
             return true;
         }
-        default:;
+        case wxsUnknownLanguage: // fall-through
+        default:
+            break;
     }
     return false;
 }
@@ -390,7 +407,9 @@ bool wxWidgetsGUI::AddSmithToApp(const wxString& RelativeFileName,wxsCodingLang
                 wxsCoder::Get()->PutFullCode(FullPath,Source,Encoding,UseBOM);
                 break;
             }
-            default:;
+            case wxsUnknownLanguage: // fall-through
+            default:
+                break;
         }
     }
 
@@ -433,7 +452,9 @@ wxString wxWidgetsGUI::GetAppClassName(const wxString& Source,wxsCodingLang Lang
             if ( Source[Pos] != _T(')') ) return wxEmptyString;
             return ClassName;
         }
-        default:;
+        case wxsUnknownLanguage: // fall-through
+        default:
+            break;
     }
     return wxEmptyString;
 }
@@ -457,10 +478,6 @@ bool wxWidgetsGUI::CreateNewApp(const wxString& FileName)
             Fl.Write(
                 _T("#include <wx/wxprec.h>\n")
                 _T("\n")
-                _T("#ifdef __BORLANDC__\n")
-                _T("    #pragma hdrstop\n")
-                _T("#endif\n")
-                _T("\n")
                 _T("#ifndef WX_PRECOMP\n")
                 _T("    #include <wx/app.h>\n")
                 _T("#endif\n")
@@ -471,8 +488,8 @@ bool wxWidgetsGUI::CreateNewApp(const wxString& FileName)
                 _T("\n")
                 _T("class MyApp : public wxApp\n")
                 _T("{\n")
-                _T("	public:\n")
-                _T("		virtual bool OnInit();\n")
+                _T("    public:\n")
+                _T("        virtual bool OnInit();\n")
                 _T("};\n")
                 _T("\n")
                 _T("IMPLEMENT_APP(MyApp);\n")
@@ -486,7 +503,9 @@ bool wxWidgetsGUI::CreateNewApp(const wxString& FileName)
                 _T("\n"));
             break;
         }
-        default:;
+        case wxsUnknownLanguage: // fall-through
+        default:
+            break;
     }
 
     // Applying default configuration
