@@ -8,14 +8,11 @@
 
 #include <wx/wxprec.h>
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
-
 //(*Headers(DataBreakpointDlg)
 #include <wx/checkbox.h>
 #include <wx/sizer.h>
 #include "scrollingdialog.h"
+#include <wx/textctrl.h>
 #include <wx/radiobox.h>
 //*)
 
@@ -23,16 +20,18 @@ class DataBreakpointDlg: public wxScrollingDialog
 {
     public:
 
-        DataBreakpointDlg(wxWindow* parent,wxWindowID id = -1,bool enabled=true,int selection=1);
+        DataBreakpointDlg(wxWindow *parent, const wxString& dataExpression, bool enabled, int selection);
         virtual ~DataBreakpointDlg();
 
         //(*Identifiers(DataBreakpointDlg)
-        static const long ID_CHECKBOX1;
-        static const long ID_RADIOBOX1;
+        static const long ID_CHK_ENABLED;
+        static const long ID_TXT_DATA_EXPRESION;
+        static const long ID_RDO_CONDITION;
         //*)
-        
-        bool IsEnabled();
+
+        bool IsBreakpointEnabled();
         int GetSelection();
+        wxString GetDataExpression() const;
 
     protected:
 
@@ -40,9 +39,9 @@ class DataBreakpointDlg: public wxScrollingDialog
         //*)
 
         //(*Declarations(DataBreakpointDlg)
-        wxCheckBox* CheckBox1;
-		wxBoxSizer* BoxSizer1;
-        wxRadioBox* RadioBox1;
+        wxRadioBox* m_condition;
+        wxCheckBox* m_enabled;
+        wxTextCtrl* m_dataExpression;
         wxStdDialogButtonSizer* StdDialogButtonSizer1;
         //*)
 
