@@ -2,9 +2,9 @@
  * This file is part of the Code::Blocks IDE and licensed under the GNU General Public License, version 3
  * http://www.gnu.org/licenses/gpl-3.0.html
  *
- * $Revision: 5580 $
- * $Id: msvcloader.cpp 5580 2009-05-03 13:43:23Z biplab $
- * $HeadURL: svn+ssh://jenslody@svn.berlios.de/svnroot/repos/codeblocks/trunk/src/plugins/projectsimporter/msvcloader.cpp $
+ * $Revision: 12999 $
+ * $Id: msvcloader.cpp 12999 2022-11-01 13:12:28Z wh11204 $
+ * $HeadURL: https://svn.code.sf.net/p/codeblocks/code/trunk/src/plugins/projectsimporter/msvcloader.cpp $
  */
 
 #include "sdk.h"
@@ -100,7 +100,7 @@ bool MSVCLoader::Open(const wxString& filename)
     return ParseSourceFiles();
 }
 
-bool MSVCLoader::Save(const wxString& filename)
+bool MSVCLoader::Save(cb_unused const wxString& filename)
 {
     // no support to save MSVC projects
     return false;
@@ -211,11 +211,7 @@ bool MSVCLoader::ReadConfigurations()
             {
                 m_Configurations.Add(tmp);
                 m_ConfigurationsLineIndex.Add(currentLine);
-                #if wxCHECK_VERSION(2, 9, 0)
-                Manager::Get()->GetLogManager()->DebugLog(F(_T("Detected configuration '%s' at line %d"), tmp.wx_str(), currentLine));
-                #else
-                Manager::Get()->GetLogManager()->DebugLog(F(_T("Detected configuration '%s' at line %d"), tmp.c_str(), currentLine));
-                #endif
+                Manager::Get()->GetLogManager()->DebugLog(wxString::Format("Detected configuration '%s' at line %d", tmp, currentLine));
             }
         }
     }
@@ -524,8 +520,8 @@ void MSVCLoader::ProcessCompilerOptions(ProjectBuildTarget* target, const wxStri
                 wxArrayString options;
                 if (ParseResponseFile(m_pProject->GetBasePath() + opt.Mid(1), options))
                 {
-                    for (size_t i = 0; i < options.GetCount(); ++i)
-                        ProcessCompilerOptions(target, options[i]);
+                    for (size_t j = 0; j < options.GetCount(); ++j)
+                        ProcessCompilerOptions(target, options[j]);
                 }
                 else
                 { // Fallback: Remember GCC will process Pre-processor macros only
@@ -592,6 +588,11 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
             {
                 // do nothing (ignore silently)
             }
+            else if (opt.Matches(_T("/dll")))
+            {
+                opt = opt.Mid(4);
+                target->AddLinkerOption(_T("--dll ") + RemoveQuotes(opt));
+            }
             else if (opt.StartsWith(_T("/out:")))
             {
                 // do nothing; it is handled below, in common options
@@ -601,8 +602,8 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
                 wxArrayString options;
                 if (ParseResponseFile(m_pProject->GetBasePath() + opt.Mid(1), options))
                 {
-                    for (size_t i = 0; i < options.GetCount(); ++i)
-                        ProcessLinkerOptions(target, options[i]);
+                    for (size_t j = 0; j < options.GetCount(); ++j)
+                        ProcessLinkerOptions(target, options[j]);
                 } // else ignore
             }
             else if (opt.Find(_T(".lib")) == -1) // don't add linking lib (added below, in common options)
@@ -652,11 +653,14 @@ void MSVCLoader::ProcessLinkerOptions(ProjectBuildTarget* target, const wxString
                 if (newf.IsRelative())
                     newf.MakeAbsolute(m_pProject->GetBasePath());
                 Compiler* compiler = CompilerFactory::GetCompiler(m_pProject->GetCompilerID());
-                newf.SetExt(compiler->GetSwitches().libExtension);
-                wxString name = newf.GetName();
-                wxString prefix = compiler->GetSwitches().libPrefix;
-                if (!prefix.IsEmpty() && !name.StartsWith(prefix))
-                    newf.SetName(prefix + name);
+                if (compiler)
+                {
+                    newf.SetExt(compiler->GetSwitches().libExtension);
+                    wxString name = newf.GetName();
+                    wxString prefix = compiler->GetSwitches().libPrefix;
+                    if (!prefix.IsEmpty() && !name.StartsWith(prefix))
+                        newf.SetName(prefix + name);
+                }
                 target->SetOutputFilename(newf.GetFullPath());
             }
             else
