@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     2007-08-19
-// RCS-ID:      $Id: switcherdlg.cpp,v 1.6 2007/08/20 17:38:24 anthemion Exp $
+// RCS-ID:      $Id: switcherdlg.cpp 12604 2021-12-22 08:48:07Z wh11204 $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWidgets licence
 /////////////////////////////////////////////////////////////////////////////
@@ -41,7 +41,7 @@ void wxSwitcherItem::Init()
     m_breakColumn = false;
     m_rowPos = 0;
     m_colPos = 0;
-    m_window = NULL;
+    m_window = nullptr;
 }
 
 void wxSwitcherItem::Copy(const wxSwitcherItem& item)
@@ -96,7 +96,7 @@ bool wxSwitcherItems::operator== (const wxSwitcherItems& items) const
 
     if (m_backgroundColour != items.m_backgroundColour || m_textColour != items.m_textColour ||
         m_selectionColour != items.m_selectionColour || m_selectionOutlineColour != items.m_selectionOutlineColour ||
-        m_itemFont != items.m_itemFont)
+        m_selectionTextColour != items.m_selectionTextColour || m_itemFont != items.m_itemFont)
         return false;
 
     size_t i;
@@ -115,12 +115,14 @@ void wxSwitcherItems::Init()
     m_rowCount = 10;
     m_columnCount = 0;
 
-#if defined(__WXMSW__) && wxUSE_UXTHEME
+#if defined(__WXMSW__) && wxUSE_UXTHEME &&!wxCHECK_VERSION(3, 1, 1)
     // If on Windows XP/Vista, use more appropriate colours.
+    // Alatar: What for??? Why should we use fixed colours?
     if (wxUxThemeEngine::GetIfActive())
     {
         SetSelectionOutlineColour(wxColour(49, 106, 197));
         SetSelectionColour(wxColour(193,210, 238));
+        SetSelectionTextColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT));
     }
 #endif
 }
@@ -143,6 +145,7 @@ void wxSwitcherItems::Copy(const wxSwitcherItems& items)
     m_textColour = items.m_textColour;
     m_selectionColour = items.m_selectionColour;
     m_selectionOutlineColour = items.m_selectionOutlineColour;
+    m_selectionTextColour = items.m_selectionTextColour;
     m_itemFont = items.m_itemFont;
 }
 
@@ -157,6 +160,18 @@ wxSwitcherItem& wxSwitcherItems::AddItem(const wxString& title, const wxString&
     return AddItem(item);
 }
 
+wxSwitcherItem& wxSwitcherItems::AddItem(const wxString& title, const wxString& name, const wxString& descr, int id, const wxBitmap& bitmap)
+{
+    wxSwitcherItem item;
+    item.SetTitle(title);
+    item.SetName(name);
+    item.SetDescription(descr);
+    item.SetId(id);
+    item.SetBitmap(bitmap);
+
+    return AddItem(item);
+}
+
 wxSwitcherItem& wxSwitcherItems::AddItem(const wxSwitcherItem& item)
 {
     m_items.Add(item);
@@ -228,9 +243,10 @@ void wxSwitcherItems::PaintItems(wxDC& dc, wxWindow* win)
     wxColour standardTextColour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
     wxColour selectionColour = wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHT);
     wxColour selectionOutlineColour = wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT);
+    wxColour selectionTextColour = wxSystemSettings::GetColour(wxSYS_COLOUR_HIGHLIGHTTEXT);
     wxFont standardFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
     wxFont groupFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    groupFont.SetWeight(wxBOLD);
+    groupFont.SetWeight(wxFONTWEIGHT_BOLD);
 
     if (GetBackgroundColour().Ok())
         backgroundColour = GetBackgroundColour();
@@ -244,11 +260,14 @@ void wxSwitcherItems::PaintItems(wxDC& dc, wxWindow* win)
     if (GetSelectionOutlineColour().Ok())
         selectionOutlineColour = GetSelectionOutlineColour();
 
+    if (GetSelectionTextColour().Ok())
+        selectionTextColour = GetSelectionTextColour();
+
     if (GetItemFont().Ok())
     {
         standardFont = GetItemFont();
         groupFont = wxFont(standardFont.GetPointSize(), standardFont.GetFamily(), standardFont.GetStyle(),
-            wxBOLD, standardFont.GetUnderlined(), standardFont.GetFaceName());
+            wxFONTWEIGHT_BOLD, standardFont.GetUnderlined(), standardFont.GetFaceName());
     }
 
     int textMarginX = wxSWITCHER_TEXT_MARGIN_X;
@@ -277,7 +296,9 @@ void wxSwitcherItems::PaintItems(wxDC& dc, wxWindow* win)
 
         dc.SetClippingRegion(clippingRect);
 
-        if (item.GetTextColour().Ok())
+        if (selected)
+            dc.SetTextForeground(selectionTextColour);
+        else if (item.GetTextColour().Ok())
             dc.SetTextForeground(item.GetTextColour());
         else
             dc.SetTextForeground(standardTextColour);
@@ -324,7 +345,7 @@ wxSize wxSwitcherItems::CalculateItemSize(wxDC& dc)
     wxSize sz(150, 16);
     wxFont standardFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
     wxFont groupFont = wxSystemSettings::GetFont(wxSYS_DEFAULT_GUI_FONT);
-    groupFont.SetWeight(wxBOLD);
+    groupFont.SetWeight(wxFONTWEIGHT_BOLD);
 
     int textMarginX = wxSWITCHER_TEXT_MARGIN_X;
     int textMarginY = wxSWITCHER_TEXT_MARGIN_Y;
@@ -426,11 +447,7 @@ bool wxMultiColumnListCtrl::Create(wxWindow* parent, wxWindowID id, const wxPoin
 {
     wxControl::Create(parent, id, pos, size, style);
 
-    #if wxCHECK_VERSION(2, 8, 0)
     SetInitialSize(size);
-    #else
-    SetInitialBestSize(size);
-    #endif
 
     return true;
 }
@@ -471,8 +488,6 @@ void wxMultiColumnListCtrl::OnPaint(wxPaintEvent& WXUNUSED(event))
     wxPaintDC dc(this);
 #endif
 
-    wxRect rect = GetClientRect();
-
     if (m_items.GetColumnCount() == 0)
         CalculateLayout(dc);
 
@@ -509,25 +524,40 @@ void wxMultiColumnListCtrl::OnMouseEvent(wxMouseEvent& event)
 
         Refresh();
     }
-    else
+    else if (event.GetButton() == wxMOUSE_BTN_NONE)
+    {   // Mouse move
+        bool bCanSelectItem = true;
+        if (m_ptMouse.x != -2 && m_ptMouse.y != -2)
+        {   // If ==-2 => Don't select item on mouse pointer : used when user select the window with keyboard
+            if (m_ptMouse.x != -1 && m_ptMouse.y != -1)
+            {   // If ==-1 => The client already move the mouse, select the item under the mouse cursor
+                wxPoint ptCurrent = ClientToScreen(event.GetPosition());
+                if (abs(ptCurrent.x - m_ptMouse.x) >= 3 || abs(ptCurrent.y - m_ptMouse.y) >= 3)
+                {   // the user has moved the mouse over a 3 pixels square
+                    m_ptMouse.x = m_ptMouse.y = -1; // Accept to select an item
+                }
+                else
+                {   // Select this item is not allowed for the moment, the user must move the mouse
+                    bCanSelectItem = false;
+                }
+            }
+            if (bCanSelectItem)
+            {
+                int idx = m_items.HitTest(event.GetPosition());
+                if (idx != wxNOT_FOUND)
+                {
+                    m_items.SetSelection(idx);
+                    GenerateSelectionEvent();
+                    Refresh();
+                }
+            }
+        }
+    }
+    else if (event.LeftDown())
     {
-        int idx = m_items.HitTest(event.GetPosition());
-
-        if (idx != wxNOT_FOUND)
-        {
-            m_items.SetSelection(idx);
-
-            GenerateSelectionEvent();
-
-            Refresh();
-        }
-
-        if (event.LeftDown())
-        {
-            SendCloseEvent();
-
-            SetFocus();
-        }
+        m_ptMouse.x = m_ptMouse.y = -1; // Accept to select an item
+        SendCloseEvent();
+        SetFocus();
     }
 }
 
@@ -541,14 +571,19 @@ void wxMultiColumnListCtrl::OnKey(wxKeyEvent& event)
     {
         if (event.GetKeyCode() == GetModifierKey())
         {
+            // The window will close, don't select the item under mouse pointer
+            m_ptMouse.x = m_ptMouse.y = -2;
             SendCloseEvent();
         }
         event.Skip();
         return;
     }
 
-    if (event.GetKeyCode() == WXK_ESCAPE || event.GetKeyCode() == WXK_RETURN)
+    if (event.GetKeyCode() == WXK_ESCAPE || event.GetKeyCode() == WXK_RETURN || event.GetKeyCode() == WXK_NUMPAD_ENTER)
     {
+        // The window will close, don't select the item under mouse pointer
+        m_ptMouse.x = m_ptMouse.y = -2;
+
         if (event.GetKeyCode() == WXK_ESCAPE)
             m_items.SetSelection(-1);
 
@@ -802,6 +837,7 @@ void wxMultiColumnListCtrl::Init()
     m_overallSize = wxSize(200, 100);
     m_modifierKey = WXK_CONTROL;
     m_extraNavigationKey = 0;
+    m_ptMouse = wxGetMousePosition();
 }
 
 /*!
@@ -848,11 +884,7 @@ bool wxSwitcherDialog::Create( const wxSwitcherItems& items, wxWindow *parent, w
         m_listCtrl->SetModifierKey(m_modifierKey);
 
     int borderStyle = wxSIMPLE_BORDER;
-
-    borderStyle = wxBORDER_NONE;
-#if defined(__WXMSW__) && wxCHECK_VERSION(2,8,5)
-    // borderStyle = wxBORDER_THEME;
-#endif
+        borderStyle = wxBORDER_NONE;
 
     m_descriptionCtrl = new wxHtmlWindow(this, wxID_ANY, wxDefaultPosition, wxSize(-1, 100), borderStyle);
     m_descriptionCtrl->SetHTMLBackgroundColour(GetBackgroundColour());
@@ -886,15 +918,15 @@ bool wxSwitcherDialog::Create( const wxSwitcherItems& items, wxWindow *parent, w
 
 void wxSwitcherDialog::Init()
 {
-    m_listCtrl = NULL;
-    m_descriptionCtrl = NULL;
+    m_listCtrl = nullptr;
+    m_descriptionCtrl = nullptr;
     m_closing = false;
     m_switcherBorderStyle = 0;
 
     m_modifierKey = -1;
     m_extraNavigationKey = -1;
 
-#if defined(__WXMSW__) && wxUSE_UXTHEME
+#if defined(__WXMSW__) && wxUSE_UXTHEME &&!wxCHECK_VERSION(3, 1, 1)
     if (wxUxThemeEngine::GetIfActive())
         m_borderColour = wxColour(49, 106, 197);
     else
